from __future__ import unicode_literals

from django.core.management.base import BaseCommand
from django.core.validators import validate_email
from django.core.exceptions import ValidationError
from django.contrib.auth import get_user_model
from guardian.shortcuts import assign_perm


class Command(BaseCommand):
    help = 'Used to define a user as institutional responsible.'

    def add_arguments(self, parser):
        parser.add_argument(
            'email', nargs='+', help='Specifies the login for the superuser.',
        )

    def handle(self, *args, **options):
        User = get_user_model()  # NOQA
        for email in options.get('email'):
            try:
                validate_email(email)
                user = User.objects.get(email=email)
            except ValidationError:
                self.print_error("Invalid email '{}'".format(email))
            except User.DoesNotExist:
                self.print_error("User with email '{}' does not exists"
                                 .format(email))
            else:
                user.is_institutional_responsible = True
                user.save(update_fields=['is_institutional_responsible'])
                assign_perm("evoteprocesses.add_electoralprocess", user)
                assign_perm("evoteprocesses.change_electoralprocess", user)
                self.print_success("User with email {} setted as "
                                   "institutional responsible".format(email))

    def print_success(self, msg):
        self.stdout.write(self.style.SUCCESS(msg))

    def print_error(self, msg):
        self.stderr.write(self.style.ERROR(msg))
