from __future__ import unicode_literals

from django.utils.translation import ugettext as _
from django.db.models import F

from evotedocs.documents import PdfDocument


class ElectoralRollPdf(PdfDocument):

    def set_story(self, **kwargs):
        electoral_roll = kwargs.get('electoral_roll')
        self.story.append(self.title(
            _("Electoral Roll of {}".format(
                electoral_roll.election.identifier))))
        self.add_header_table(electoral_roll)
        self.add_voters_table(electoral_roll)

    def add_header_table(self, electoral_roll):
        """ Adds the header of page to story """
        table_data = []
        table_data.append([
            self.get_reload_icon(),
            _('Version: {}'.format(electoral_roll.version)),
            self.get_calendar_icon(),
            _('Publication date: {}'.format(self.get_formated_date(
                electoral_roll.published_on, body=False, icon=False)))
        ])
        self.story.append(self.custom_header_table(
            table_data, col_widths=[15, 150, 15, 150]))

    def add_voters_table(self, electoral_roll):
        """ Adds table of voters to story """
        table_data = []
        table_data.append([
            _('Name'),
            _('Number'),
            _('Voting weight')
        ])
        for voter in electoral_roll.election_voters.annotate(
                category_weight=F("category__weight")):
            table_data.append([
                voter.name,
                voter.personnel_number,
                voter.category_weight
            ])
        self.story.append(self.long_table(table_data, header=True))

    def get_title(self, **kwargs):
        electoral_roll = kwargs.get('electoral_roll')
        return _("Electoral Roll of {}".format(electoral_roll.election))
